﻿using DevExpress.Data;
using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid;
using DevExpress.XtraGrid.Views.Base;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                true,                           // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                true                            // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridView.OptionsView.ShowFooter = true;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.ProductsTableAdapter().GetData();

            #region 그리드 컬럼 SUMMARY 항목을 추가한다.

            GridColumnSummaryItem gridColumnSummaryItem  = new GridColumnSummaryItem();

            gridColumnSummaryItem.FieldName     = "UnitPrice";
            gridColumnSummaryItem.SummaryType   = SummaryItemType.Average;
            gridColumnSummaryItem.DisplayFormat = "{0:c2}";

            this.gridView.Columns["UnitPrice"].Summary.Add(gridColumnSummaryItem);

            #endregion

            this.gridView.BestFitColumns();

            this.gridView.CellValueChanged += gridView_CellValueChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 셀 값 변경시 처리하기 - gridView_CellValueChanged(sender, e)

        /// <summary>
        /// 그리드 뷰 셀 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_CellValueChanged(object sender, CellValueChangedEventArgs e)
        {
            GridView gridView = sender as GridView;

            if(e.Column.FieldName == "UnitPrice")
            {
                gridView.UpdateTotalSummary();
            }
        }

        #endregion
    }
}